@@ -8,7 +8,14 @@
 #ifndef VMWARE_H
 #define VMWARE_H
 
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#ifdef HAVE_XORG_SERVER_1_1_0
 #include <string.h>
+#endif
 
 #include "xf86.h"
 #include "xf86_OSproc.h"
@@ -16,6 +23,10 @@
 
 #include <X11/extensions/panoramiXproto.h>
 
+#ifdef XSERVER_LIBPCIACCESS
+#include <pciaccess.h>
+#endif
+
 #include "compiler.h"	        /* inb/outb */
 
 #include "xf86PciInfo.h"	/* pci vendor id */
@@ -55,8 +66,12 @@ typedef xXineramaScreenInfo VMWAREXineramaRec, *VMWAREXineramaPtr;
 
 typedef struct {
     EntityInfoPtr pEnt;
+#if XSERVER_LIBPCIACCESS
+    struct pci_device *PciInfo;
+#else
     pciVideoPtr PciInfo;
     PCITAG PciTag;
+#endif
     Bool Primary;
     int depth;
     int bitsPerPixel;
@@ -68,6 +83,7 @@ typedef struct {
     unsigned long fbOffset;
     unsigned long fbPitch;
     unsigned long ioBase;
+    unsigned long portIOBase;
     int maxWidth;
     int maxHeight;
     unsigned int vmwareCapability;
@@ -132,6 +148,11 @@ typedef struct {
     VMWAREXineramaPtr xineramaNextState;
     unsigned int xineramaNextNumOutputs;
 
+    /*
+     * Xv
+     */
+    DevUnion *videoStreams;
+
 } VMWARERec, *VMWAREPtr;
 
 #define VMWAREPTR(p) ((VMWAREPtr)((p)->driverPrivate))
@@ -181,6 +202,20 @@ static __inline ScrnInfoPtr infoFromScreen(ScreenPtr s) {
 /* Undefine this to kill all acceleration */
 #define ACCELERATE_OPS
 
+#if XSERVER_LIBPCIACCESS
+#define VENDOR_ID(p)      (p)->vendor_id
+#define DEVICE_ID(p)      (p)->device_id
+#define SUBVENDOR_ID(p)   (p)->subvendor_id
+#define SUBSYS_ID(p)      (p)->subdevice_id
+#define CHIP_REVISION(p)  (p)->revision
+#else
+#define VENDOR_ID(p)      (p)->vendor
+#define DEVICE_ID(p)      (p)->chipType
+#define SUBVENDOR_ID(p)   (p)->subsysVendor
+#define SUBSYS_ID(p)      (p)->subsysCard
+#define CHIP_REVISION(p)  (p)->chipRev
+#endif
+
 void vmwareWriteReg(
    VMWAREPtr pVMWARE, int index, CARD32 value
    );
@@ -208,6 +243,11 @@ DisplayModeRec *VMWAREAddDisplayMode(
     int height
    );
 
+Bool vmwareIsRegionEqual(
+    const RegionPtr reg1,
+    const RegionPtr reg2
+   );
+
 /* vmwarecurs.c */
 Bool vmwareCursorInit(
    ScreenPtr pScr
@@ -239,4 +279,19 @@ void VMwareCtrl_ExtInit(ScrnInfoPtr pScrn);
 /* vmwarexinerama.c */
 void VMwareXinerama_ExtInit(ScrnInfoPtr pScrn);
 
+/* vmwarevideo.c */
+Bool vmwareVideoInit(
+   ScreenPtr pScreen
+   );
+void vmwareVideoEnd(
+   ScreenPtr pScreen
+   );
+Bool vmwareVideoEnabled(
+   VMWAREPtr pVMWARE
+   );
+
+void vmwareCheckVideoSanity(
+   ScrnInfoPtr pScrn
+   );
+
 #endif
